lavalink_rs.model.search API documentation

# lavalink_rs.model.search

class SpotifyRecommendedParameters:

Any of the seed fields must have a value.

Spotify documentation can be found here

target_acousticness: float
min_valence: float
max_popularity: int
max_duration_ms: int
limit: int
max_danceability: float
max_instrumentalness: float
max_liveness: float
min_loudness: int
target_tempo: int
target_valence: float
target_speechiness: float
target_popularity: int
market: str
target_key: float
max_loudness: int
min_speechiness: float
max_time_signature: float
seed_artists: str
min_time_signature: float
min_key: float
target_time_signature: float
min_danceability: float
min_tempo: int
max_valence: float
min_acousticness: float
target_liveness: float
max_energy: float
max_key: float
max_acousticness: float
min_energy: float
seed_tracks: str
target_duration_ms: int
target_danceability: float
target_energy: float
target_mode: float
max_speechiness: float
min_instrumentalness: float
min_popularity: int
max_mode: float
min_duration_ms: int
target_instrumentalness: float
target_loudness: int
max_tempo: int
min_mode: float
min_liveness: float
seed_genres: str
class FloweryTTSParameters:
voice: str

A list of voices can be found here

translate: bool

TODO: Document this.

audio_format: str

Supported formats are: mp3, ogg_opus, ogg_vorbis, aac, wav, and flac.

silence: int

The silence parameter is in milliseconds. Range is 0 to 10000. The default is 0.

speed: float

The speed parameter is a float between 0.5 and 10. The default is 1.0. (0.5 is half speed, 2.0 is double speed, etc.)